# Table of Contents

- [netskope-integration-for-saas-discovery](<./netskope-integration-for-saas-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Netskope Integration for SaaS Discovery](<./Netskope-Integration-for-SaaS-Discovery.md>)
  - [Introduction](<./Netskope-Integration-for-SaaS-Discovery/Introduction.md>)
  - [Implementation Details](<./Netskope-Integration-for-SaaS-Discovery/Implementation-Details.md>)
  - [Discovery Capabilities](<./Netskope-Integration-for-SaaS-Discovery/Discovery-Capabilities.md>)
  - [Setting up Netskope Integration](<./Netskope-Integration-for-SaaS-Discovery/Setting-up-Netskope-Integration.md>)
  - [Create New API Token in Netskope](<./Netskope-Integration-for-SaaS-Discovery/Create-New-API-Token-in-Netskope.md>)
  - [Enter the Necessary Credentials in SAP LeanIX](<./Netskope-Integration-for-SaaS-Discovery/Enter-the-Necessary-Credentials-in-SAP-LeanIX.md>)
  - [Was this page helpful?](<./Netskope-Integration-for-SaaS-Discovery/Was-this-page-helpful.md>)
